%define module	gmpy
%define _exclude_files_from_autoprov %{python_sitearch}/.*\\.so %{python3_sitearch}/.*\\.so

Summary:	Python interface to GMP
Name:		python-%{module}
Version:	1.17
Release:	%mkrel 3
Source0:	http://gmpy.googlecode.com/files/%{module}-%{version}.zip
License: 	LGPLv2.1
Group: 		Development/Python
Url: 		http://code.google.com/p/gmpy/
# GMP versions before 4.2.4 have a bug that cause gmpy to segfault.
Requires:	libgmp >= 4.2.4
BuildRequires:	libgmp-devel >= 4.2.4
BuildRequires:  pkgconfig(python)

%description
The General Multiprecision PYthon project (GMPY) focuses on
Python-usable modules providing multiprecision arithmetic
functionality to Python programmers. The project mission includes both
C and C++ Python-modules (for speed) and pure Python modules (for
flexibility and convenience); it potentially includes integral,
rational and floating-point arithmetic in any base. Only
cross-platform functionality is of interest, at least for now.

%package -n python3-%{module}
Summary:	Python 3 interface to GMP
Group:		Development/Python
BuildRequires:	pkgconfig(python3)

%description -n python3-%{module}
The General Multiprecision PYthon project (GMPY) focuses on
Python 3 usable modules providing multiprecision arithmetic
functionality to Python 3 programmers. The project mission includes both
C and C++ Python-modules (for speed) and pure Python 3 modules (for
flexibility and convenience); it potentially includes integral,
rational and floating-point arithmetic in any base. Only
cross-platform functionality is of interest, at least for now.


%prep
%setup -q -n %{module}-%{version}
cp -a . %{py3dir} 

%build
find -name .svn | xargs rm -rf
CFLAGS="%{optflags}" %{__python} setup.py build

pushd %{py3dir} 
CFLAGS="%{optflags}" %{__python3} setup.py build
popd

%install
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root %{buildroot}
chmod 755 %{buildroot}%{python3_sitearch}/gmpy*.so
popd

%{__python} setup.py install --skip-build --root %{buildroot}
chmod 755 %{buildroot}%{python_sitearch}/gmpy.so

%check
# Make python see the library that we have just compiled
libdir=`ls build/|grep lib`
export PYTHONPATH=`pwd`/build/$libdir

cd test
%{__python} gmpy_test.py

pushd %{py3dir}
# Make python see the library that we have just compiled
libdir=`ls build/|grep lib`
export PYTHONPATH=`pwd`/build/$libdir

cd test
%{__python3} gmpy_test.py
popd

%files
%doc README doc/ test/
%{python_sitearch}/gmpy.so
%{python_sitearch}/gmpy-%{version}-py*.egg-info


%files -n python3-%{module}
%doc README doc/ test/
%{python3_sitearch}/gmpy*.so
%{python3_sitearch}/gmpy-%{version}-py*.egg-info




%changelog
* Tue Oct 22 2013 umeabot <umeabot> 1.17-3.mga4
+ Revision: 543490
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.17-2.mga4
+ Revision: 498697
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Sep 11 2013 philippem <philippem> 1.17-1.mga4
+ Revision: 477791
- update to 1.17, add Python 3

* Sun Jan 13 2013 umeabot <umeabot> 1.16-2.mga3
+ Revision: 378921
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 kamil <kamil> 1.16-1.mga3
+ Revision: 324744
- new version 1.16

* Thu Jul 26 2012 kamil <kamil> 1.15-1.mga3
+ Revision: 274418
- new version 1.15
- update Source0

* Thu Jul 26 2012 kamil <kamil> 1.14-2.mga3
+ Revision: 274413
- adapt for Mageia
- imported package python-gmpy


* Mon Dec 13 2010 Lev Givon <lev@mandriva.org> 1.14-1mdv2011.0
+ Revision: 620654
- Update to 1.14.

* Sat Nov 06 2010 Funda Wang <fwang@mandriva.org> 1.12-2mdv2011.0
+ Revision: 594037
- rebuld for py 2.7

* Mon Jul 19 2010 Lev Givon <lev@mandriva.org> 1.12-1mdv2011.0
+ Revision: 554995
- Update to 1.12.

* Wed Feb 10 2010 Funda Wang <fwang@mandriva.org> 1.11-1mdv2010.1
+ Revision: 503561
- New version 1.11
- rebuild for new gmp

* Sun Dec 27 2009 Frederik Himpe <fhimpe@mandriva.org> 1.10-1mdv2010.1
+ Revision: 482849
- Update to new version 1.10

* Wed Apr 01 2009 Lev Givon <lev@mandriva.org> 1.04-1mdv2010.0
+ Revision: 363390
- Update to 1.04.

* Fri Jul 11 2008 Lev Givon <lev@mandriva.org> 1.03-1mdv2009.0
+ Revision: 233834
- Update to 1.03.

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 1.01-3mdv2008.1
+ Revision: 136448
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request


* Sun Jan 21 2007 Nicolas Lécureuil <neoclust@mandriva.org> 1.01-3mdv2007.0
+ Revision: 111518
- Rebuicl for new python
- import python-gmpy-1.01-2mdk

* Thu May 04 2006 Nicolas Lcureuil <neoclust@mandriva.org> 1.01-2mdk
- Add BuildRequires
- Fix mkrel for rpmbuildupdate

* Wed May 03 2006 Lev Givon <lev@columbia.edu> 1.01-1mdk
- Initial Mandriva package.

